import * as C from './convert.js';
import { Bytes, Data, Json } from './types.js';
type BufferLike = Buff | ArrayBuffer | ArrayBufferLike | Uint8Array | string | number | bigint | boolean;
type HashTypes = 'sha256' | 'hash256' | 'ripe160' | 'hash160';
type Endian = 'le' | 'be';
export declare class Buff extends Uint8Array {
    static num: (number: number, size?: number, endian?: Endian) => Buff;
    static big: (number: bigint, size?: number, endian?: Endian) => Buff;
    static b58check(data: string): Buff;
    static any: (data: any, size?: number) => Buff;
    static raw: (data: ArrayBufferLike, size?: number) => Buff;
    static str: (data: string, size?: number) => Buff;
    static hex: (data: string, size?: number) => Buff;
    static json: (data: Json) => Buff;
    static bytes: (data: Bytes, size?: number) => Buff;
    static base64: (data: string) => Buff;
    static b64url: (data: string) => Buff;
    static bech32: (data: string, ver?: number) => Buff;
    static bech32m: (data: string) => Buff;
    constructor(data: BufferLike, size?: number);
    get num(): number;
    get big(): bigint;
    get arr(): number[];
    get str(): string;
    get hex(): string;
    get raw(): Uint8Array;
    get base64(): string;
    get b64url(): string;
    get digest(): Buff;
    get id(): string;
    get stream(): Stream;
    toNum(endian?: Endian): number;
    toBig(endian?: Endian): bigint;
    toHash(type?: HashTypes): Buff;
    toHmac(key: string | Uint8Array): Buff;
    tob58check(): string;
    toArr(): number[];
    toStr(): string;
    toHex(): string;
    toJson(): Json;
    toBytes(): Uint8Array;
    toB64url(): string;
    toBase64(): string;
    toBech32(hrp: string, ver?: number): string;
    toBech32m(hrp: string): string;
    prepend(data: Uint8Array): Buff;
    append(data: Uint8Array): Buff;
    slice(start?: number, end?: number): Buff;
    reverse(): Buff;
    write(bytes: Uint8Array, offset?: number): void;
    prefixSize(endian?: Endian): Buff;
    static from(data: Uint8Array | number[]): Buff;
    static of(...args: number[]): Buff;
    static join(arr: Uint8Array[]): Buff;
    static readSize(num: number, endian?: Endian): Buff;
    static random(size?: number): Buff;
    static encode: typeof C.strToBytes;
    static decode: typeof C.bytesToStr;
    static normalize(data: Bytes, size?: number): Uint8Array;
    static serialize(data: Data): Uint8Array;
    static revitalize(data: Data): Json;
}
export declare class Stream {
    size: number;
    data: Uint8Array;
    constructor(data: ArrayBufferLike);
    peek(size: number): Buff;
    read(size: number): Buff;
    readSize(): number;
}
export declare const Hex: {
    encode: (x: Uint8Array) => string;
    decode: (x: string) => Uint8Array;
    normalize: (x: Bytes) => Uint8Array;
    serialize: (x: Bytes) => string;
};
export declare const Txt: {
    encode: (x: Uint8Array) => string;
    decode: (x: string) => Uint8Array;
    serialzie: (x: Data) => Uint8Array;
    revitalize: (x: Data) => Json;
};
export {};
//# sourceMappingURL=buff.d.ts.map